@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:03:12
-@LastEditTime: 2023-02-17 10:35:04
+@LastEditTime: 2023-02-24 17:51:55
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -26,13 +26,19 @@ class ActInfoHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        ver_no = self.get_param("ver_no", "1")
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        ver_no = invoke_result_data.data["ver_no"] if invoke_result_data.data.__contains__("ver_no") else '1'
         if ver_no == "1":
-            self.v1()
+            self.get_act_info()
         else:
-            self.v2()
+            self.get_act_info_v2()
+
+    def get_act_info(self):
 
-    def v1(self):
         app_id = self.get_app_id()
         act_id = self.get_act_id()
         app_base_model = AppBaseModel(context=self)
@@ -56,7 +62,8 @@ class ActInfoHandler(ClientBaseHandler):
         act_info_dict = self.business_process_executed(act_info_dict, ref_params={})
         return self.response_json_success(act_info_dict)
 
-    def v2(self):
+    def get_act_info_v2(self):
+
         app_id = self.get_app_id()
         act_id = self.get_act_id()
         app_base_model = AppBaseModel(context=self)
@@ -104,8 +111,6 @@ class ActInfoHandler(ClientBaseHandler):
         return self.response_json_success(act_info_dict)
 
 
-
-
 class ActPrizeListHandler(ClientBaseHandler):
     """
     :description: 活动奖品列表
