@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2023-02-21 14:51:15
+@LastEditTime: 2023-03-14 13:39:09
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -41,7 +41,11 @@ class TaskInfoListHandler(ClientBaseHandler):
         if not invoke_result_data.data:
             invoke_result_data.data = {}
         daily_repeat_browse = invoke_result_data.data["daily_repeat_browse"] if invoke_result_data.data.__contains__("daily_repeat_browse") else False
-        result_list,task_info_list,task_count_list = task_base_model.get_client_task_list(app_id, act_id, module_id, user_id, task_types, app_key, app_secret, is_log, daily_repeat_browse, mix_nick)
+        ver_no = invoke_result_data.data["ver_no"] if invoke_result_data.data.__contains__("ver_no") else '1'
+        if ver_no == "1":
+            result_list,task_info_list,task_count_list = task_base_model.get_client_task_list(app_id, act_id, module_id, user_id, task_types, app_key, app_secret, is_log, daily_repeat_browse, mix_nick)
+        else:
+            result_list,task_info_list,task_count_list = task_base_model.get_client_task_list_v2(app_id, act_id, module_id, user_id, task_types, daily_repeat_browse)
         ref_params = {}
         ref_params["task_info_list"] = task_info_list
         ref_params["task_count_list"] = task_count_list
@@ -125,12 +129,14 @@ class FreeGiftHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if not invoke_result_data.data:
             invoke_result_data.data = {}
+
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else True
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else True  #是否直接领取奖励
         info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
-        invoke_result_data = task_base_model.process_free_gift(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json)
+        invoke_result_data = task_base_model.process_free_gift(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json, is_receive_reward)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -167,12 +173,14 @@ class OneSignHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if not invoke_result_data.data:
             invoke_result_data.data = {}
+
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else False
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else True  #是否直接领取奖励
         info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else {}
-        invoke_result_data = task_base_model.process_one_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json)
+        invoke_result_data = task_base_model.process_one_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json, is_receive_reward)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -215,8 +223,9 @@ class WeeklySignHandler(ClientBaseHandler):
         check_act_module_release = invoke_result_data.data["check_act_module_release"] if invoke_result_data.data.__contains__("check_act_module_release") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else True  #是否直接领取奖励
         info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
-        invoke_result_data = task_base_model.process_weekly_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json, check_act_info_release=check_act_info_release, check_act_module_release=check_act_module_release)
+        invoke_result_data = task_base_model.process_weekly_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json, check_act_info_release=check_act_info_release, check_act_module_release=check_act_module_release, is_receive_reward=is_receive_reward)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -257,8 +266,9 @@ class CumulativeSignHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else True  #是否直接领取奖励
         info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
-        invoke_result_data = task_base_model.process_cumulative_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat,info_json)
+        invoke_result_data = task_base_model.process_cumulative_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json, is_receive_reward)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -498,8 +508,9 @@ class FavorStoreHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else True  #是否直接领取奖励
         info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
-        invoke_result_data = task_base_model.process_favor_store(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_user_nick, continue_request_expire, is_stat, info_json)
+        invoke_result_data = task_base_model.process_favor_store(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_user_nick, continue_request_expire, is_stat, info_json, is_receive_reward)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -539,8 +550,9 @@ class JoinMemberHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else True  #是否直接领取奖励
         info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
-        invoke_result_data = task_base_model.process_join_member(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_user_nick, continue_request_expire, is_stat, info_json)
+        invoke_result_data = task_base_model.process_join_member(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_user_nick, continue_request_expire, is_stat, info_json, is_receive_reward)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -552,7 +564,7 @@ class JoinMemberHandler(ClientBaseHandler):
 
 class BrowseSiteHandler(ClientBaseHandler):
     """
-    :description: 处理浏览网址相关任务 如：浏览店铺、浏览直播间、浏览会场/专题
+    :description: 处理浏览网址相关任务 如：浏览会场/专题
     """
     @filter_check_params("login_token", check_user_code=True)
     def get_async(self):
@@ -577,7 +589,7 @@ class BrowseSiteHandler(ClientBaseHandler):
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
         invoke_result_data = InvokeResultData()
-        if task_type not in [TaskType.browse_store.value,TaskType.browse_live_room.value,TaskType.browse_special_topic.value]:
+        if task_type not in [TaskType.browse_special_topic.value]:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
@@ -604,7 +616,6 @@ class BrowseSiteHandler(ClientBaseHandler):
         return self.response_json_success(0)
 
 
-
 class ShareHandler(ClientBaseHandler):
     """
     :description: 分享任务
@@ -648,3 +659,193 @@ class ShareHandler(ClientBaseHandler):
             if invoke_result_data.success == True:
                 return self.response_json_success(invoke_result_data.data)
         return self.response_json_success(0)
+
+
+class BrowseStoreHandler(ClientBaseHandler):
+    """
+    :description: 浏览店铺任务
+    """
+    @filter_check_params("login_token", check_user_code=True)
+    def get_async(self):
+        """
+        :description: 浏览店铺任务
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_code:用户标识
+        :param login_token:访问令牌
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
+        user_id = self.get_user_id()
+        module_id = int(self.get_param("module_id", 0))
+        login_token = self.get_param("login_token")
+        task_type = TaskType.browse_store.value
+        task_base_model = TaskBaseModel(context=self)
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else False  #是否直接领取奖励
+        invoke_result_data = task_base_model.process_routine_task(task_type, app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, False, False)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if is_receive_reward == True:
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=14, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=True, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            if invoke_result_data.success == True:
+                return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(0)
+
+
+class BrowseLiveRoomHandler(ClientBaseHandler):
+    """
+    :description: 浏览直播间任务
+    """
+    @filter_check_params("login_token", check_user_code=True)
+    def get_async(self):
+        """
+        :description: 浏览直播间任务
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_code:用户标识
+        :param login_token:访问令牌
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
+        user_id = self.get_user_id()
+        module_id = int(self.get_param("module_id", 0))
+        login_token = self.get_param("login_token")
+        task_type = TaskType.browse_live_room.value
+        task_base_model = TaskBaseModel(context=self)
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else False  #是否直接领取奖励
+        invoke_result_data = task_base_model.process_routine_task(task_type, app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, False, False)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if is_receive_reward == True:
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=14, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=True, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            if invoke_result_data.success == True:
+                return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(0)
+
+
+class InviteUserHelpHandler(ClientBaseHandler):
+    """
+    :description: 处理邀请用户助力任务(被邀请人进入调用)
+    """
+    @filter_check_params("invite_user_id,login_token", check_user_code=True)
+    def get_async(self):
+        """
+        :description: 处理邀请用户助力任务(被邀请人进入调用)
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_code:用户标识
+        :param invite_user_id:邀请人用户标识
+        :param login_token:访问令牌
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
+        user_id = self.get_user_id()
+        module_id = int(self.get_param("module_id", 0))
+        login_token = self.get_param("login_token")
+        from_user_id = int(self.get_param("invite_user_id", 0))
+        task_base_model = TaskBaseModel(context=self)
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        check_act_info_release = invoke_result_data.data["check_act_info_release"] if invoke_result_data.data.__contains__("check_act_info_release") else True
+        check_act_module_release = invoke_result_data.data["check_act_module_release"] if invoke_result_data.data.__contains__("check_act_module_release") else True
+        is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else False #是否统计
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else False #是否直接领取奖励
+
+        stat_base_model = StatBaseModel(context=self)
+        if is_stat == True:
+            stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, "", {"BeInvitedHelpUserCount": 1, "BeInvitedHelpCount": 1})
+
+        invoke_result_data = task_base_model.process_invite_user_help(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, 5, check_act_info_release=check_act_info_release, check_act_module_release=check_act_module_release)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if is_stat == True:
+            stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, "", {"AddBeInvitedHelpUserCount": 1})
+
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if is_receive_reward == True:
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=from_user_id, login_token='', task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=4, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=True, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            if invoke_result_data.success == True:
+                return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(0)
+
+
+class SecretCodeHandler(ClientBaseHandler):
+    """
+    :description: 神秘暗号任务
+    """
+    @filter_check_params("login_token,secret_code", check_user_code=True)
+    def get_async(self):
+        """
+        :description: 神秘暗号任务
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_code:用户标识
+        :param login_token:访问令牌
+        :param secret_code:暗号
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
+        user_id = self.get_user_id()
+        module_id = self.get_param_int("module_id", 0)
+        login_token = self.get_param("login_token")
+        secret_code = self.get_param("secret_code")
+        task_base_model = TaskBaseModel(context=self)
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else False
+        check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
+        continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
+        is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else False  #是否直接领取奖励
+        invoke_result_data = task_base_model.process_secret_code(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, secret_code, check_new_user, check_user_nick, continue_request_expire)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if is_receive_reward == True:
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=14, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=True, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            if invoke_result_data.success == True:
+                return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(0)
\ No newline at end of file
