@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2023-01-12 09:52:44
+@LastEditTime: 2023-03-01 17:35:06
 @LastEditors: HuangJianYi
 @Description: 用户模块
 """
@@ -381,6 +381,7 @@ class AssetLogListHandler(ClientBaseHandler):
         :description: 资产流水记录
         :param app_id：应用标识
         :param act_id：活动标识
+        :param module_id：模块标识
         :param asset_type：资产类型(1-次数2-积分3-价格档位)
         :param page_size：条数
         :param page_index：页数
@@ -398,6 +399,7 @@ class AssetLogListHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
+        module_id = self.get_param_int("module_id", 0)
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
         user_id = self.get_user_id()
@@ -418,7 +420,7 @@ class AssetLogListHandler(ClientBaseHandler):
         else:
             field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         asset_base_model = AssetBaseModel(context=self)
-        page_list, total = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id, field, is_cache=False, operate_type=operate_type)
+        page_list, total = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id, field, is_cache=False, operate_type=operate_type, module_id=module_id)
         ref_params = {}
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
         return self.response_json_success(page_info)
