@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2023-02-10 09:57:56
+@LastEditTime: 2023-03-07 15:50:43
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -545,4 +545,50 @@ class SevenHelper:
                     return enum.value
             return default_value
         except:
-            return default_value
\ No newline at end of file
+            return default_value
+
+    @classmethod
+    def to_int(self, value):
+        """
+        :description: 转换成整形
+        :param value:值
+        :return:整形
+        :last_editors: HuangJianYi
+        """
+        try:
+            value = int(value)
+        except Exception as ex:
+            value = 0
+        return value
+
+    @classmethod
+    def get_row_by_dict_list(self, dict_list, field_name, field_type=1):
+        """
+        :description: 获取字典列表中指定列的集合
+        :param field_name:字段名
+        :param field_type:字段类型（1整形2字符串）
+        :return:数组
+        :last_editors: HuangJianYi
+        """
+        if isinstance(dict_list,list) == False:
+            return []
+        if field_type == 1:
+            return [int(item[field_name]) for item in dict_list]
+        else:
+            return [str(item[field_name]) for item in dict_list]
+
+    @classmethod   
+    def replace_value_to_list(self, data_list, old_item, new_item):
+        """
+        :description: 替换列表中指定元素，旧值换新值
+        :param old_item:旧元素(可对象、字典)
+        :param new_item:新元素(可对象、字典)
+        :return:list
+        :last_editors: HuangJianYi
+        """
+        try:
+            data_index = data_list.index(old_item)
+            data_list[data_index] = new_item
+        except:
+            pass
+        return data_list
\ No newline at end of file
