@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2023-02-10 10:21:25
+@LastEditTime: 2023-03-14 14:19:09
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -743,6 +743,230 @@ class WeChatHelper:
         except Exception:
             raise "WeixinPaySignIError"
 
+    @classmethod
+    def generate_scheme(self, app_id="", app_secret="", page="pages/index/index", query="", env_version="release", is_expire=True, expire_type=1, expire_interval=30, expire_time=0):
+        """
+        :description: 该接口用于获取小程序 scheme 码，适用于短信、邮件、外部网页、微信内等拉起小程序的业务场景。通过该接口，可以选择最长30天有效的小程序码，有数量限制，目前仅针对国内非个人主体的小程序开放
+        :param app_id:app_id
+        :param app_secret:app_secret
+        :param page: 页面 page，例如 pages/theme/theme，根路径前不要填加
+        :param query: 查询条件，例如 source_id=1&query1=q1
+        :param env_version: 默认值"release"。要打开的小程序版本。正式版为"release"，体验版为"trial"，开发版为"develop"，仅在微信外打开时生效。
+        :param is_expire: 到期失效的 scheme 码的失效时间，为 Unix 时间戳。生成的到期失效 scheme 码在该时间前有效。最长有效期为30天。is_expire 为 true 且 expire_type 为 0 时必填
+        :param expire_type: 默认值0，到期失效的 scheme 码失效类型，失效时间：0，失效间隔天数：1
+        :param expire_interval: 到期失效的 scheme 码的失效间隔天数。生成的到期失效 scheme 码在该间隔时间到达前有效。最长间隔天数为30天。is_expire 为 true 且 expire_type 为 1 时必填
+        :param expire_time: 到期失效的 scheme 码的失效时间，为 Unix 时间戳。生成的到期失效 scheme 码在该时间前有效。最长有效期为30天。is_expire 为 true 且 expire_type 为 0 时必填
+        :return: InvokeResultData
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+
+        if expire_type == 1 and expire_interval > 30:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "URL Scheme有效期最长30天"
+            return invoke_result_data
+        elif expire_type == 0 and TimeHelper.difference_days(expire_time, TimeHelper.get_now_timestamp()) > 30:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "URL Scheme有效期最长30天"
+            return invoke_result_data
+
+        redis_init = SevenHelper.redis_init(decode_responses=False)
+        redis_key = "generate_scheme:" + CryptoHelper.md5_encrypt(f"{page}_{query}_{env_version}_{is_expire}_{expire_type}_{expire_interval}_{expire_time}")
+        redis_value = redis_init.get(redis_key)
+        if redis_value:
+            invoke_result_data.data = redis_value.decode()
+            return invoke_result_data
+
+        for i in range(2):
+            if i == 0:
+                invoke_result_data = WeChatHelper.get_access_token(app_id, app_secret)
+            else:
+                invoke_result_data = WeChatHelper.get_access_token(app_id, app_secret, True)
+
+            if invoke_result_data.success == True:
+                break
+        if invoke_result_data.success == False:
+            return invoke_result_data
+
+        access_token = invoke_result_data.data
+        response = ""
+        response_data = {}
+        try:
+            headers = {"Content-type": "application/json"}
+            requset_url = 'https://api.weixin.qq.com/wxa/generatescheme?access_token=' + access_token
+            param = {"jump_wxa": {"path": page, "query": query, "env_version": env_version}, "is_expire": is_expire, "expire_type": expire_type, "expire_interval": expire_interval, "expire_time": expire_time}
+            try:
+                response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers=headers)
+                response_data = SevenHelper.json_loads(response.text)
+                if response_data.__contains__("errcode") and response_data["errcode"] != 0:
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code = response_data["errcode"]
+                    invoke_result_data.error_message = response_data["errmsg"]
+                    return invoke_result_data
+            except:
+                pass
+            invoke_result_data.data = response_data['openlink']
+            if expire_type == 1 and expire_interval > 0:
+                redis_init.set(redis_key, invoke_result_data.data, expire_interval * 24 * 3600)
+            elif expire_type == 0 and expire_time > 0:
+                redis_init.set(redis_key, invoke_result_data.data, 300)
+                redis_init.expireat(redis_key, expire_time)
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【generate_scheme】" + traceback.format_exc() + ":" + str(response.text))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+
+    @classmethod
+    def generate_urllink(self, app_id="", app_secret="", page="pages/index/index", query="", env_version="release", is_expire=True, expire_type=1, expire_interval=30, expire_time=0, cloud_base=None):
+        """
+        :description: 获取小程序 URL Link，适用于短信、邮件、网页、微信内等拉起小程序的业务场景。通过该接口，可以选择最长30天有效的小程序链接，有数量限制，目前仅针对国内非个人主体的小程序开放
+        :param app_id:app_id
+        :param app_secret:app_secret
+        :param page: 页面 page，例如 pages/theme/theme，根路径前不要填加
+        :param query: 查询条件，例如 source_id=1&query1=q1
+        :param env_version: 默认值"release"。要打开的小程序版本。正式版为"release"，体验版为"trial"，开发版为"develop"，仅在微信外打开时生效。
+        :param is_expire: 到期失效的 scheme 码的失效时间，为 Unix 时间戳。生成的到期失效 scheme 码在该时间前有效。最长有效期为30天。is_expire 为 true 且 expire_type 为 0 时必填
+        :param expire_type: 默认值0，到期失效的 scheme 码失效类型，失效时间：0，失效间隔天数：1
+        :param expire_interval: 到期失效的 scheme 码的失效间隔天数。生成的到期失效 scheme 码在该间隔时间到达前有效。最长间隔天数为30天。is_expire 为 true 且 expire_type 为 1 时必填
+        :param expire_time: 到期失效的 scheme 码的失效时间，为 Unix 时间戳。生成的到期失效 scheme 码在该时间前有效。最长有效期为30天。is_expire 为 true 且 expire_type 为 0 时必填
+        :param cloud_base: 云开发静态网站自定义 H5 配置参数，可配置中转的云开发 H5 页面。不填默认用官方 H5 页面 例如{"env": "云开发环境，如：xxx", "domain": "静态网站自定义域名，不填则使用默认域名，如：xxx.xxx", "path": "云开发静态网站 H5 页面路径，不可携带 query如：/jump-wxa.html", "query": "云开发静态网站 H5 页面 query 参数，最大 1024 个字符，只支持数字，大小写英文以及部分特殊字符：`!#$&'()*+,/:;=?@-._~%``如：a=1&b=2", "resource_appid": "第三方批量代云开发时必填，表示创建该 env 的 appid （小程序/第三方平台）"}
+        :return: InvokeResultData
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+
+        if expire_type == 1 and expire_interval > 30:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "URL Link有效期最长30天"
+            return invoke_result_data
+        elif expire_type == 0 and TimeHelper.difference_days(expire_time, TimeHelper.get_now_timestamp()) > 30:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "URL Link有效期最长30天"
+            return invoke_result_data
+
+        redis_init = SevenHelper.redis_init(decode_responses=False)
+        redis_key = "generate_urllink:" + CryptoHelper.md5_encrypt(f"{page}_{query}_{env_version}_{is_expire}_{expire_type}_{expire_interval}_{expire_time}_{cloud_base}")
+        redis_value = redis_init.get(redis_key)
+        if redis_value:
+            invoke_result_data.data = redis_value.decode()
+            return invoke_result_data
+
+        for i in range(2):
+            if i == 0:
+                invoke_result_data = WeChatHelper.get_access_token(app_id, app_secret)
+            else:
+                invoke_result_data = WeChatHelper.get_access_token(app_id, app_secret, True)
+
+            if invoke_result_data.success == True:
+                break
+        if invoke_result_data.success == False:
+            return invoke_result_data
+
+        access_token = invoke_result_data.data
+        response = ""
+        response_data = {}
+        try:
+            headers = {"Content-type": "application/json"}
+            requset_url = 'https://api.weixin.qq.com/wxa/generate_urllink?access_token=' + access_token
+            param = {"path": page, "query": query, "env_version": env_version, "is_expire": is_expire, "expire_type": expire_type, "expire_interval": expire_interval, "expire_time": expire_time, "cloud_base": cloud_base}
+            try:
+                response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers=headers)
+                response_data = SevenHelper.json_loads(response.text)
+                if response_data.__contains__("errcode") and response_data["errcode"] != 0:
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code = response_data["errcode"]
+                    invoke_result_data.error_message = response_data["errmsg"]
+                    return invoke_result_data
+            except:
+                pass
+            invoke_result_data.data = response_data['url_link']
+            if expire_type == 1 and expire_interval > 0:
+                redis_init.set(redis_key, invoke_result_data.data, expire_interval * 24 * 3600)
+            elif expire_type == 0 and expire_time > 0:
+                redis_init.set(redis_key, invoke_result_data.data, 300)
+                redis_init.expireat(redis_key, expire_time)
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【generate_urllink】" + traceback.format_exc() + ":" + str(response.text))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+
+    @classmethod
+    def generate_shortlink(self, app_id="", app_secret="", page="pages/index/index", query="", page_title="", is_permanent=False):
+        """
+        :description: 获取小程序 Short Link，适用于微信内拉起小程序的业务场景。目前只开放给电商类目(具体包含以下一级类目：电商平台、商家自营、跨境电商)。通过该接口，可以选择生成到期失效和永久有效的小程序短链
+        :param app_id:app_id
+        :param app_secret:app_secret
+        :param page: 页面 page，例如 pages/theme/theme，根路径前不要填加
+        :param query: 查询条件，例如 source_id=1&query1=q1
+        :param page_title: 页面标题，不能包含违法信息，超过20字符会用... 截断代替
+        :param is_permanent: 默认值false。生成的 Short Link 类型，短期有效：false，永久有效：true
+        :return: InvokeResultData
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+
+        redis_init = SevenHelper.redis_init(decode_responses=False)
+        redis_key = "generate_shortlink:" + CryptoHelper.md5_encrypt(f"{page}_{query}_{page_title}_{is_permanent}")
+        redis_value = redis_init.get(redis_key)
+        if redis_value:
+            invoke_result_data.data = redis_value.decode()
+            return invoke_result_data
+
+        for i in range(2):
+            if i == 0:
+                invoke_result_data = WeChatHelper.get_access_token(app_id, app_secret)
+            else:
+                invoke_result_data = WeChatHelper.get_access_token(app_id, app_secret, True)
+
+            if invoke_result_data.success == True:
+                break
+        if invoke_result_data.success == False:
+            return invoke_result_data
+
+        access_token = invoke_result_data.data
+        response = ""
+        response_data = {}
+        try:
+            headers = {"Content-type": "application/json"}
+            requset_url = 'https://api.weixin.qq.com/wxa/genwxashortlink?access_token=' + access_token
+            param = {"page_url": f"{page}?{query}", "page_title": page_title, "is_permanent": is_permanent}
+            try:
+                response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers=headers)
+                response_data = SevenHelper.json_loads(response.text)
+                if response_data.__contains__("errcode") and response_data["errcode"] != 0:
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code = response_data["errcode"]
+                    invoke_result_data.error_message = response_data["errmsg"]
+                    return invoke_result_data
+            except:
+                pass
+            invoke_result_data.data = response_data['link']
+            if is_permanent == True:
+                redis_init.set(redis_key, invoke_result_data.data)
+            else:
+                redis_init.set(redis_key, invoke_result_data.data, 30 * 24 * 3600)
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【generate_shortlink】" + traceback.format_exc() + ":" + str(response.text))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+
+
+
+
+
 
 class WeChatPayRequest(object):
     """
