@@ -217,7 +217,7 @@ class AppBaseModel():
                 app_info.expiration_date = dead_date
             if project_code != "":
                 app_info.project_code = project_code
-            invoke_result_data = top_base_model.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
+            invoke_result_data = top_base_model.get_shop(access_token, app_key, app_secret)
             if invoke_result_data.success == True:
                 app_info.access_token = access_token
             if app_info.main_user_open_id != main_user_open_id:
