@@ -146,34 +146,35 @@ class CacheModel(BaseModel):
 
     def delete_dependency_key(self, dependency_key='', delay_delete_time=0.01):
         """
-        :Description: 删除依赖键,支持延迟删除和重试机制
+        :Description: 删除依赖键,支持延迟删除和重试机制，同时删除多个依赖建建议传数组，不要分开多次调用
         :param dependency_key: 依赖键,为空则删除默认依赖建
         :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
         :last_editors: HuangJianYi
         """
-        count = 0
-        while count < 2:
-            count += 1
-            try:
-                success_count = 0
-                redis_init = self.__redis_init()
-                if delay_delete_time > 0:
-                    time.sleep(delay_delete_time)
-                if isinstance(dependency_key,list):
-                    for key in dependency_key:
-                        is_del = redis_init.delete(self.get_dependency_key(key))
-                        if is_del == 1:
-                            success_count += 1
-                    if success_count == len(dependency_key):
-                        break
-                else:
-                    success_count = redis_init.delete(self.get_dependency_key(dependency_key))
-                    if success_count == 1:
-                        break
-            except:
-                print(traceback.print_exc())
-                pass
+        if share_config.get_value("is_redis_cache",True) == True:
+            count = 0
+            while count < 2:
+                count += 1
+                try:
+                    success_count = 0
+                    redis_init = self.__redis_init()
+                    if delay_delete_time > 0:
+                        time.sleep(delay_delete_time)
+                    if isinstance(dependency_key,list):
+                        for key in dependency_key:
+                            is_del = redis_init.delete(self.get_dependency_key(key))
+                            if is_del == 1:
+                                success_count += 1
+                        if success_count == len(dependency_key):
+                            break
+                    else:
+                        success_count = redis_init.delete(self.get_dependency_key(dependency_key))
+                        if success_count == 1:
+                            break
+                except:
+                    print(traceback.print_exc())
+                    pass
 
     def get_cache_list(self, where='', group_by='', order_by='', limit='', field="*", params=None,dependency_key='', cache_expire=1800):
         """
