@@ -34,7 +34,7 @@ class AssetConsoleModel():
 
         t = threading.Thread(target=self._process_asset_intercept_queue, args=[])
         t.start()
-        
+
     def _process_onlyid_warn(self):
         """
         :description: 处理唯一值并发预警
@@ -217,7 +217,10 @@ class AssetConsoleModel():
                     now_value = asset_queue_dict["now_value"]
                     operate_value = asset_queue_dict["operate_value"]
                     history_asset_value = asset_queue_dict["history_asset_value"]
-                    asset_inventory_id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{asset_type}_{asset_object_id}_{now_day_int}")
+                    if act_id > 0:
+                        asset_inventory_id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{asset_type}_{asset_object_id}_{now_day_int}")
+                    else:
+                        asset_inventory_id_md5 = CryptoHelper.md5_encrypt_int(f"{app_id}_0_{user_id}_{asset_type}_{asset_object_id}_{now_day_int}")
                     asset_inventory = asset_inventory_model.get_entity("id_md5=%s",params=[asset_inventory_id_md5])
                     asset_inventory_update_sql = f"process_count=0,now_value={now_value}"
                     if asset_inventory:
