@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-24 09:36:39
-@LastEditTime: 2023-02-06 15:29:13
+@LastEditTime: 2023-02-08 10:04:51
 @LastEditors: HuangJianYi
 @Description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流) 需在配置文件加 armor_url 和 armor_sign_key对应的值
 """
@@ -10,6 +10,7 @@
 import threading, multiprocessing
 from seven_framework import *
 from seven_framework.console.base_console import *
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
 from seven_cloudapp_frame.models.db_models.erp.erp_relation_model import *
@@ -50,8 +51,8 @@ class ErpConsoleModel():
         :last_editors: HuangJianYi
         """
         page_size = 100
-        push_url = config.get_value("armor_url","") + "/api/new_order"
-        sign_key = config.get_value("armor_sign_key", "")
+        push_url = share_config.get_value("armor_url", "") + "/api/new_order"
+        sign_key = share_config.get_value("armor_sign_key", "")
 
         print(f"{TimeHelper.get_now_format_time()} 推送订单队列{mod_value}启动")
 
@@ -81,7 +82,6 @@ class ErpConsoleModel():
                                 prize_order_list_dict = prize_order_model.get_dict_list(condition, "", order_by="id asc", limit=str(page_size), field="*", params=params)
                                 for prize_order_dict in prize_order_list_dict:
                                     request_params = self.compose_push_request_params(sign_key, erp_relation_dict, prize_order_dict, prize_roster_model)
-                                    request_params = self.process_order_push_executed(request_params, erp_relation_dict)
                                     if request_params["goods"]:
                                         result = HTTPHelper.post(push_url, request_params, {"Content-Type": "application/json"})
                                         if result and result.ok:
@@ -165,16 +165,6 @@ class ErpConsoleModel():
         data["sign"] = SignHelper.params_sign_md5(data, sign_key)
         return data
 
-    def process_order_push_executed(self, request_params, erp_relation_dict):
-        """
-        :description: 
-        :param request_params: 请求参数
-        :param erp_relation_dict: erp关联信息
-        :return: 
-        :last_editors: HuangJianYi
-        """
-        return request_params
-
     def process_order_pull(self, mod_value, mod_count, process_type=1):
         """
         :description: 处理订单拉取，同步物流信息
@@ -238,8 +228,8 @@ class ErpConsoleModel():
                                     erp_redis_init.lpop(key)
                             else:
                                 page_size = 100
-                                pull_url = config.get_value("armor_url","") + "/api/new_get_order"
-                                sign_key = config.get_value("armor_sign_key", "")
+                                pull_url = share_config.get_value("armor_url","") + "/api/new_get_order"
+                                sign_key = share_config.get_value("armor_sign_key", "")
                                 condition = "app_id=%s and order_status=0 and sync_status=1"
                                 params = [erp_relation_dict["app_id"]]
                                 record_count = prize_order_model.get_total(condition, params=params)
