@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2023-02-10 15:08:33
+@LastEditTime: 2023-03-01 14:54:31
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -99,10 +99,10 @@ class StatConsoleModel():
                             is_add = True
                             if stat_orm.repeat_type > 0:
                                 if stat_orm.repeat_type == 2:
-                                    stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id])
+                                    stat_log_dict = stat_log_model.get_dict("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", field="id", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id])
                                 else:
-                                    stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id, create_day_int])
-                                if stat_log_total > 0:
+                                    stat_log_dict = stat_log_model.get_dict("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", field="id", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id, create_day_int])
+                                if stat_log_dict:
                                     is_add = False
 
                             stat_log = StatLog()
@@ -119,11 +119,11 @@ class StatConsoleModel():
 
                             stat_report_condition = "act_id=%s and module_id=%s and key_name=%s and create_day=%s"
                             stat_report_param = [stat_queue.act_id, stat_queue.module_id, stat_queue.key_name, create_day_int]
-                            stat_report_total = stat_report_model.get_cache_total(stat_report_condition, params=stat_report_param)
+                            stat_report_dict = stat_report_model.get_dict(stat_report_condition, params=stat_report_param)
 
                             db_transaction.begin_transaction()
                             if is_add:
-                                if stat_report_total == 0:
+                                if not stat_report_dict:
                                     stat_report = StatReport()
                                     stat_report.app_id = stat_queue.app_id
                                     stat_report.act_id = stat_queue.act_id
@@ -193,10 +193,10 @@ class StatConsoleModel():
                     is_add = True
                     if stat_orm.repeat_type > 0:
                         if stat_orm.repeat_type == 2:
-                            stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"]])
+                            stat_log_dict = stat_log_model.get_dict("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", field="id", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"]])
                         else:
-                            stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"], create_day_int])
-                        if stat_log_total > 0:
+                            stat_log_dict = stat_log_model.get_dict("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", field="id", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"], create_day_int])
+                        if stat_log_dict:
                             is_add = False
 
                     stat_log = StatLog()
@@ -213,11 +213,11 @@ class StatConsoleModel():
 
                     stat_report_condition = "act_id=%s and module_id=%s and key_name=%s and create_day=%s"
                     stat_report_param = [stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"], create_day_int]
-                    stat_report_total = stat_report_model.get_cache_total(stat_report_condition, params=stat_report_param)
+                    stat_report_dict = stat_report_model.get_dict(stat_report_condition, params=stat_report_param)
 
                     if is_add:
                         db_transaction.begin_transaction()
-                        if stat_report_total == 0:
+                        if not stat_report_dict:
                             stat_report = StatReport()
                             stat_report.app_id = stat_queue_dict["app_id"]
                             stat_report.act_id = stat_queue_dict["act_id"]
@@ -291,8 +291,8 @@ class StatConsoleModel():
 
                     stat_report_condition = "act_id=%s and module_id=%s and create_day=%s and user_id=%s"
                     stat_report_param = [stat_queue_dict["act_id"], stat_queue_dict["module_id"], create_day_int, stat_queue_dict["user_id"]]
-                    stat_report_total = stat_user_report_model.get_total(stat_report_condition, params=stat_report_param)
-                    if stat_report_total == 0:
+                    stat_report_dict = stat_user_report_model.get_dict(stat_report_condition, params=stat_report_param)
+                    if not stat_report_dict:
                         stat_user_report = StatUserReport()
                         stat_user_report.app_id = stat_queue_dict["app_id"]
                         stat_user_report.act_id = stat_queue_dict["act_id"]
