@@ -28,6 +28,7 @@ class ThemeInfo:
         super(ThemeInfo, self).__init__()
         self.id = 0  # id
         self.app_id = ""  # 应用唯一标识
+        self.ascription_type = 1  #归属类型(1公共)
         self.theme_name = ""  # 主题名称
         self.server_json = ""  # 服务端内容json
         self.out_id = ""  # 外部id
@@ -39,7 +40,7 @@ class ThemeInfo:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'theme_name', 'server_json', 'out_id', 'style_type', 'sort_index', 'is_release', 'create_date', 'modify_date']
+        return ['id', 'app_id', 'ascription_type', 'theme_name', 'server_json', 'out_id', 'style_type', 'sort_index', 'is_release', 'create_date', 'modify_date']
 
     @classmethod
     def get_primary_key(self):
