@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-06-02 14:32:40
-@LastEditTime: 2023-01-04 09:13:12
+@LastEditTime: 2023-03-14 10:51:40
 @LastEditors: HuangJianYi
 :description: 枚举类
 """
@@ -44,7 +44,7 @@ class TaskType(Enum):
     free_gift = 1
     # 单次签到，格式：{"reward_value":0,"asset_object_id":""}  字段说明：reward_value:奖励值 asset_object_id:资产对象标识
     one_sign = 2
-    # 每周签到，格式：{"day_list":{"1": 0, "2": 0, "3": 0, "4": 0, "5": 0, "6": 0, "7": 0},"asset_object_id":""}  字段说明：day_list:每天奖励配置列表 asset_object_id:资产对象标识
+    # 每周签到(指定天数签到)，格式：{"day_list":{"1": 0, "2": 0, "3": 0, "4": 0, "5": 0, "6": 0, "7": 0},"asset_object_id":""}  字段说明：day_list:每天奖励配置列表 asset_object_id:资产对象标识
     weekly_sign = 3
     # 邀请新用户，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 limit_num:完成限制数 asset_object_id:资产对象标识
     invite_new_user = 4
@@ -58,9 +58,9 @@ class TaskType(Enum):
     collect_goods = 8
     # 浏览商品，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"goods_ids":"","goods_list":[],"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 asset_object_id:资产对象标识 limit_num:完成限制数 goods_ids:商品ID串 goods_list:商品列表
     browse_goods = 9
-    # 浏览店铺，格式：[{"id":"","reward_value":0,"link_url":"","satisfy_num":1,"limit_num":1,"asset_object_id":""}] 字段说明：id:子任务类型,必填 reward_value:奖励值 satisfy_num:满足数  link_url:链接地址 asset_object_id:资产对象标识 limit_num:完成限制数
+    # 浏览店铺(进店逛逛)，格式：{"reward_value":0,"stay_time":0,"asset_object_id":""} 字段说明：reward_value:奖励值 asset_object_id:资产对象标识 stay_time:停留时间
     browse_store = 10
-    # 浏览直播间，格式：[{"id":"","reward_value":0,"link_url":"","satisfy_num":1,"limit_num":1,"asset_object_id":""}]  字段说明：id:子任务类型,必填 reward_value:奖励值 satisfy_num:满足数  link_url:链接地址 asset_object_id:资产对象标识 limit_num:完成限制数
+    # 浏览直播间(观看直播间)，格式：{"reward_value":0,"link_url":"","stay_time":0,"asset_object_id":""}  字段说明：reward_value:奖励值 link_url:链接地址 asset_object_id:资产对象标识 stay_time:停留时间
     browse_live_room = 11
     # 浏览会场/专题，格式：[{"id":"","reward_value":0,"link_url":"","satisfy_num":1,"limit_num":1,"asset_object_id":""}] 字段说明：id:子任务类型,必填 reward_value:奖励值 satisfy_num:满足数  link_url:链接地址 asset_object_id:资产对象标识 limit_num:完成限制数
     browse_special_topic = 12
@@ -68,3 +68,7 @@ class TaskType(Enum):
     cumulative_sign = 13
     # 分享，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 limit_num:完成限制数 asset_object_id:资产对象标识
     share = 14
+    # 邀请用户助力(不判断是否新用户，可重复邀请)，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 limit_num:完成限制数 asset_object_id:资产对象标识
+    invite_user_help = 15
+    # 神秘暗号，格式：{"reward_value":0,"secret_code":"","asset_object_id":""} 字段说明：reward_value:奖励值 secret_code:暗号 asset_object_id:资产对象标识
+    secret_code = 16
