@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2023-01-04 15:25:52
+@LastEditTime: 2023-02-21 13:38:22
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -87,9 +87,9 @@ class PrizeBaseModel():
         if condition:
             where += " and " + condition
             params_list.extend(params)
-        if ascription_type !=0:
+        if ascription_type != -1:
             where += " and ascription_type=%s"
-            params_list.append(is_del)
+            params_list.append(ascription_type)
         if is_del !=-1:
             where += " and is_del=%s"
             params_list.append(is_del)
