@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2023-02-22 14:50:14
+@LastEditTime: 2023-02-27 09:48:56
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -1574,6 +1574,172 @@ class TopBaseModel():
                 return invoke_result_data
             invoke_result_data.data = resp["crm_point_change_response"]["result"]
             return invoke_result_data
+        except Exception as ex:
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
+            invoke_result_data.success = False
+            if "submsg" in str(ex):
+                content_list = str(ex).split()
+                for content in content_list:
+                    if "submsg=该子帐号无此操作权限" in content:
+                        invoke_result_data.error_code = "no_power"
+                        invoke_result_data.error_message = content[len("submsg="):]
+                        return invoke_result_data
+                    if "submsg=" in content:
+                        invoke_result_data.error_code = "error"
+                        invoke_result_data.error_message = content[len("submsg="):]
+                        return invoke_result_data
+            return invoke_result_data
+
+    def miniapp_widget_template_instance_query(self, widget_template_id, access_token, app_key, app_secret, is_log=False):
+        """
+        :description: 查询淘宝小部件信息
+        :param widget_template_id：小部件模版id
+        :param access_token：access_token
+        :param app_key:app_key
+        :param app_secret:app_secret
+        :param is_log：是否记录返回信息
+        :return 小部件实例化信息
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        try:
+            top.setDefaultAppInfo(app_key, app_secret)
+            req = top.api.MiniappWidgetTemplateInstanceQueryRequest()
+            req.param0 = {}
+            req.param0["page_size"] = 20
+            req.param0["page_num"] = 1
+            req.param0["template_id"] = widget_template_id
+            resp = req.getResponse(access_token)
+            if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【查询淘宝小部件信息】"
+                if self.context:
+                    self.context.logging_link_info(log_info)
+                elif self.logging_link_info:
+                    self.logging_link_info(log_info)
+            return invoke_result_data
+
+        except Exception as ex:
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
+            invoke_result_data.success = False
+            if "submsg" in str(ex):
+                content_list = str(ex).split()
+                for content in content_list:
+                    if "submsg=该子帐号无此操作权限" in content:
+                        invoke_result_data.error_code = "no_power"
+                        invoke_result_data.error_message = content[len("submsg="):]
+                        return invoke_result_data
+                    if "submsg=" in content:
+                        invoke_result_data.error_code = "error"
+                        invoke_result_data.error_message = content[len("submsg="):]
+                        return invoke_result_data
+            return invoke_result_data
+        
+    def miniapp_widget_template_instantiate(self, template_version, description, widget_template_id, access_token, app_key, app_secret, is_log=False):
+        """
+        :description: 实例化小部件 resp={"miniapp_widget_template_instantiate_response": {"result": {"model": {"app_description": "提供商家会员权益集合", "app_icon": "https://ossgw.alicdn.com/taobao-miniapp/img/39eb12a3c266c7a8d72e8dcb1b6a1530.png", "app_name": "天志C店_会员身份卡片", "appkey": "400013325276", "id": "3000000070599924", "online_code": "https://m.duanqu.com/?_ariver_appid=3000000070599924&_mp_code=tb&transition=present", "online_version": "0.0.1"}, "success": True}, "request_id": "15rv0rkcwiqtn"}}
+        :param template_version：小部件版本
+        :param description：小部件描述
+        :param widget_template_id：小部件模版id
+        :param access_token：access_token
+        :param app_key:app_key
+        :param app_secret:app_secret
+        :param is_log：是否记录返回信息
+        :return 实例化后的信息
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        try:
+            top.setDefaultAppInfo(app_key, app_secret)
+            req = top.api.MiniappWidgetTemplateInstantiateRequest()
+            req.param_mini_app_instantiate_template_app_simple_request = {}
+            req.param_mini_app_instantiate_template_app_simple_request["template_id"] = widget_template_id
+            req.param_mini_app_instantiate_template_app_simple_request["template_version"] = template_version
+            req.param_mini_app_instantiate_template_app_simple_request["description"] = description
+            resp = req.getResponse(access_token)
+            if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【实例化小部件】"
+                if self.context:
+                    self.context.logging_link_info(log_info)
+                elif self.logging_link_info:
+                    self.logging_link_info(log_info)
+            if "miniapp_widget_template_instantiate_response" not in resp:
+                invoke_result_data.success = False
+                return invoke_result_data
+            if "result" not in resp["miniapp_widget_template_instantiate_response"]:
+                invoke_result_data.success = False
+                return invoke_result_data
+            if resp["miniapp_widget_template_instantiate_response"]["result"]["success"] == False:
+                invoke_result_data.success = False
+                return invoke_result_data
+
+            invoke_result_data.data = resp["miniapp_widget_template_instantiate_response"]["result"]["model"]
+            return invoke_result_data
+
+        except Exception as ex:
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
+            invoke_result_data.success = False
+            if "submsg" in str(ex):
+                content_list = str(ex).split()
+                for content in content_list:
+                    if "submsg=该子帐号无此操作权限" in content:
+                        invoke_result_data.error_code = "no_power"
+                        invoke_result_data.error_message = content[len("submsg="):]
+                        return invoke_result_data
+                    if "submsg=" in content:
+                        invoke_result_data.error_code = "error"
+                        invoke_result_data.error_message = content[len("submsg="):]
+                        return invoke_result_data
+            return invoke_result_data
+        
+    def miniapp_widget_template_instance_update(self, widgets_id, widget_template_id, template_version, access_token, app_key, app_secret, is_log=False):
+        """
+        :description: 更新小部件版本
+        :param widgets_id：小部件id
+        :param widget_template_id：小部件模版id
+        :param template_version：小部件模版版本
+        :param access_token：access_token
+        :param app_key:app_key
+        :param app_secret:app_secret
+        :param is_log：是否记录返回信息
+        :return
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        try:
+            top.setDefaultAppInfo(app_key, app_secret)
+            req = top.api.MiniappWidgetTemplateInstanceUpdateRequest()
+            req.param_mini_app_instantiate_template_app_update_request = {}
+            req.param_mini_app_instantiate_template_app_update_request["entity_id"] = widgets_id
+            req.param_mini_app_instantiate_template_app_update_request["template_id"] = widget_template_id
+            req.param_mini_app_instantiate_template_app_update_request["template_version"] = template_version
+            resp = req.getResponse(access_token)
+            if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【更新小部件版本】"
+                if self.context:
+                    self.context.logging_link_info(log_info)
+                elif self.logging_link_info:
+                    self.logging_link_info(log_info)
+            if "miniapp_widget_template_instance_update_response" not in resp:
+                invoke_result_data.success = False
+                return invoke_result_data
+            if "result" not in resp["miniapp_widget_template_instance_update_response"]:
+                invoke_result_data.success = False
+                return invoke_result_data
+            if resp["miniapp_widget_template_instance_update_response"]["result"]["success"] == False:
+                invoke_result_data.success = False
+                return invoke_result_data
+            invoke_result_data.data = resp["miniapp_widget_template_instance_update_response"]["result"]["model"]
+            return invoke_result_data
+
         except Exception as ex:
             if self.context:
                 self.context.logging_link_error(traceback.format_exc())
