@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2023-02-21 09:11:19
+@LastEditTime: 2023-02-23 14:11:16
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -207,6 +207,8 @@ class UserBaseModel(FrameBaseModel):
                 user_account.login_date = now_datetime
                 user_account.login_ip = login_ip
                 user_account.id = user_account_model.add_entity(user_account)
+                if share_config.get_value("is_cache_empty",False) == True:
+                    user_account_model.delete_dependency_key(DependencyKey.user_account(open_id))
             else:
                 delete_account_cache = False
                 if user_nick and user_account.user_nick != user_nick and is_update_user_nick == True:
@@ -338,8 +340,7 @@ class UserBaseModel(FrameBaseModel):
                 user_info_dict["is_auth"] = 1 if user_info_dict["user_nick"] else 0
                 user_info_dict["modify_date"] = SevenHelper.get_now_datetime()
                 user_info_model.update_table("user_nick=%s,user_nick_encrypt=%s,avatar=%s,modify_date=%s,is_auth=%s,is_member_before=%s,is_favor_before=%s", "id=%s", params=[user_info_dict["user_nick"], user_info_dict["user_nick_encrypt"], user_info_dict["avatar"], user_info_dict["modify_date"], user_info_dict["is_auth"], user_info_dict["is_member_before"], user_info_dict["is_favor_before"], user_info_dict["id"]])
-
-                self._delete_user_info_cache(user_info_dict["act_id"], user_info_dict["id_md5"])
+                user_info_model.delete_dependency_key([DependencyKey.user_info(act_id, user_info_dict["id_md5"]), DependencyKey.user_info(act_id, "", user_info_dict["open_id"])])
 
                 update_sql = ""
                 params = []
@@ -354,7 +355,7 @@ class UserBaseModel(FrameBaseModel):
                 params.append(user_info_dict["user_id"])
                 if update_sql:
                     user_account_model.update_table(update_sql, "id=%s", params=params)
-                    user_account_model.delete_dependency_key(f"user_account:openid_" + user_info_dict["open_id"])
+                    user_account_model.delete_dependency_key(DependencyKey.user_account(user_info_dict["open_id"]))
 
         except Exception as ex:
             if self.context:
